@@ -21,7 +21,7 @@ class Cache(objects.Object):
 		self.fp = self.file_path = FilePath(self.path)
 	def set(self, data=None, group=None, id=None, format="str"):
 		if id == None:
-			data_path = gp.clean(f"{self.path}/{group}")
+			data_path = gfp.clean(f"{self.path}/{group}")
 		else:
 			data_path = gfp.clean(f"{self.path}/{group}/"+id)#.replace("/", "\\")
 		base = FilePath(data_path).base()
@@ -33,9 +33,9 @@ class Cache(objects.Object):
 		else:
 			raise ValueError(f"Unkown format: {format}.")
 		return None
-	def get(self, group=None, id=None, format="str"):
+	def get(self, group=None, id=None, format="str", default=None):
 		if id == None:
-			data_path = gp.clean(f"{self.path}/{group}")
+			data_path = gfp.clean(f"{self.path}/{group}")
 		else:
 			data_path = gfp.clean(f"{self.path}/{group}/"+id)#.replace("/", "\\")
 		base = FilePath(data_path).base()
@@ -54,13 +54,13 @@ class Cache(objects.Object):
 		try:
 			loaded = load()
 		except FileNotFoundError:
-			self.set(id=id, data="None", group=group, format=format)
+			self.set(id=id, data=str(default), group=group, format=format)
 			loaded = load()
 		if loaded in ["None","none","null"]: loaded = None
 		return loaded
 	def delete(self, group=None, id=None, forced=False, sudo=False):
 		if id == None:
-			data_path = gp.clean(f"{self.path}/{group}")
+			data_path = gfp.clean(f"{self.path}/{group}")
 		else:
 			data_path = gfp.clean(f"{self.path}/{group}/"+id)#.replace("/", "\\")
 		Files.delete(path=data_path, sudo=sudo, forced=forced)
