@@ -99,7 +99,7 @@ class Output(ResponseObject):
 				return False
 	# support 'in' operator.
 	def __contains__(self, string):
-		if isinstance(path, (list, Array)):
+		if isinstance(string, (list, Array)):
 			for i in string:
 				if i in self.str:
 					return True
