@@ -1,6 +1,7 @@
 
 # imports
 from syst3m.classes.config import *
+from syst3m.classes import objects, defaults
 
 # utils.
 def check_os(supported=["linux"], error=False):
@@ -14,38 +15,34 @@ def coming_soon():
 	raise ValueError("COMING SOON.")
 
 # the disks object class.
-class Disks(threading.Thread):
+class Disks(objects.Object):
 	def __init__(self):
 		
-		# objects.
-		self.ext4 = Ext4()
+		# defaults.
+		objects.Object.__init__(self, traceback="syst3m.disks")
 
 		#
 	def list(self):
 		coming_soon()
+
 		# check os.
 		response = check_os()
 		if not response.success: return response
 
 		#
-
-# the ext4 object class.
-class Ext4(threading.Thread):
-	def __init__(self):
-		a=1
 	def erase(self, 
 		# the device without partition number (/dev/sdb).
 		device=None,
 	):
-		coming_soon()
+
 		# check parameters.
 		response = r3sponse.check_parameters({
 			"device:str":device,})
 		if not response.success: return response
 
 		# check os.
-		response = check_os()
-		if not response.success: return response
+		if defaults.vars.os not in ["linux"]:
+			return r3sponse.error(f"Unsupported operating system [{defaults.vars.os}].")
 
 		# handler.
 		if "SUCCESS!" in output:
