@@ -61,7 +61,7 @@ class Env(object):
 				exported = {}
 			for key,value in dictionary.items():
 				exported[str(key)] = value
-			Files.save(export, exported)
+			Files.save(export, exported, format="json")
 		return r3sponse.success(f"Successfully exported {len(dictionary)} env variables.")
 		#
 	# get.
